@@ -16,10 +16,16 @@ from openstack import proxy
 
 
 class BaseBlockStorageProxy(proxy.Proxy, metaclass=abc.ABCMeta):
-
     def create_image(
-            self, name, volume, allow_duplicates,
-            container_format, disk_format, wait, timeout):
+        self,
+        name,
+        volume,
+        allow_duplicates,
+        container_format,
+        disk_format,
+        wait,
+        timeout,
+    ):
         if not disk_format:
             disk_format = self._connection.config.config['image_format']
         if not container_format:
@@ -33,7 +39,8 @@ class BaseBlockStorageProxy(proxy.Proxy, metaclass=abc.ABCMeta):
             if not volume_obj:
                 raise exceptions.SDKException(
                     "Volume {volume} given to create_image could"
-                    " not be found".format(volume=volume))
+                    " not be found".format(volume=volume)
+                )
             volume_id = volume_obj['id']
         data = self.post(
             '/volumes/{id}/action'.format(id=volume_id),
@@ -42,7 +49,11 @@ class BaseBlockStorageProxy(proxy.Proxy, metaclass=abc.ABCMeta):
                     'force': allow_duplicates,
                     'image_name': name,
                     'container_format': container_format,
-                    'disk_format': disk_format}})
+                    'disk_format': disk_format,
+                }
+            },
+        )
         response = self._connection._get_and_munchify(
-            'os-volume_upload_image', data)
+            'os-volume_upload_image', data
+        )
         return self._connection.image._existing_image(id=response['image_id'])
