@@ -10,9 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# import types so that we can reference ListType in sphinx param declarations.
-# We can't just use list, because sphinx gets confused by
-# openstack.resource.Resource.list and openstack.resource2.Resource.list
 from openstack.accelerator.v2._proxy import Proxy
 
 
@@ -70,7 +67,7 @@ class AcceleratorCloudMixin:
         """
         device_profile = self.accelerator.get_device_profile(
             name_or_id,
-            filters
+            filters,
         )
         if device_profile is None:
             self.log.debug(
@@ -104,7 +101,7 @@ class AcceleratorCloudMixin:
         """
         accelerator_request = self.accelerator.get_accelerator_request(
             name_or_id,
-            filters
+            filters,
         )
         if accelerator_request is None:
             self.log.debug(
