@@ -10,10 +10,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# import types so that we can reference ListType in sphinx param declarations.
-# We can't just use list, because sphinx gets confused by
-# openstack.resource.Resource.list and openstack.resource2.Resource.list
-import types  # noqa
 import warnings
 
 from openstack.block_storage.v3._proxy import Proxy
@@ -21,23 +17,13 @@ from openstack.block_storage.v3 import quota_set as _qs
 from openstack.cloud import _utils
 from openstack.cloud import exc
 from openstack import exceptions
-from openstack import proxy
 from openstack import warnings as os_warnings
 
 
-def _no_pending_volumes(volumes):
-    """If there are any volumes not in a steady state, don't cache"""
-    for volume in volumes:
-        if volume['status'] not in ('available', 'error', 'in-use'):
-            return False
-    return True
-
-
 class BlockStorageCloudMixin:
     block_storage: Proxy
 
     # TODO(stephenfin): Remove 'cache' in a future major version
-    @_utils.cache_on_arguments(should_cache_fn=_no_pending_volumes)
     def list_volumes(self, cache=True):
         """List all available volumes.
 
@@ -52,7 +38,6 @@ class BlockStorageCloudMixin:
         return list(self.block_storage.volumes())
 
     # TODO(stephenfin): Remove 'get_extra' in a future major version
-    @_utils.cache_on_arguments()
     def list_volume_types(self, get_extra=None):
         """List all available volume types.
 
@@ -171,8 +156,6 @@ class BlockStorageCloudMixin:
 
         volume = self.block_storage.create_volume(**kwargs)
 
-        self.list_volumes.invalidate(self)
-
         if volume['status'] == 'error':
             raise exc.OpenStackCloudException("Error in creating volume")
 
@@ -200,8 +183,6 @@ class BlockStorageCloudMixin:
 
         volume = self.block_storage.update_volume(volume, **kwargs)
 
-        self.list_volumes.invalidate(self)
-
         return volume
 
     def set_volume_bootable(self, name_or_id, bootable=True):
@@ -245,8 +226,6 @@ class BlockStorageCloudMixin:
         :raises: OpenStackCloudTimeout if wait time exceeded.
         :raises: OpenStackCloudException on operation error.
         """
-
-        self.list_volumes.invalidate(self)
         volume = self.block_storage.find_volume(name_or_id)
 
         if not volume:
@@ -262,7 +241,6 @@ class BlockStorageCloudMixin:
             self.log.exception("error in deleting volume")
             raise
 
-        self.list_volumes.invalidate(self)
         if wait:
             self.block_storage.wait_for_delete(volume, wait=timeout)
 
@@ -283,7 +261,6 @@ class BlockStorageCloudMixin:
                     volumes.append(volume)
         return volumes
 
-    # TODO(stephenfin): Convert to use proxy
     def get_volume_limits(self, name_or_id=None):
         """Get volume limits for the current project
 
@@ -292,23 +269,12 @@ class BlockStorageCloudMixin:
         :returns: The volume ``Limit`` object if found, else None.
         """
         params = {}
-        project_id = None
-        error_msg = "Failed to get limits"
         if name_or_id:
-            proj = self.get_project(name_or_id)
-            if not proj:
+            project = self.get_project(name_or_id)
+            if not project:
                 raise exc.OpenStackCloudException("project does not exist")
-            project_id = proj.id
-            params['tenant_id'] = project_id
-            error_msg = "{msg} for the project: {project} ".format(
-                msg=error_msg, project=name_or_id
-            )
-
-        data = proxy._json_response(
-            self.block_storage.get('/limits', params=params)
-        )
-        limits = self._get_and_munchify('limits', data)
-        return limits
+            params['project'] = project
+        return self.block_storage.get_limits(**params)
 
     def get_volume_id(self, name_or_id):
         """Get ID of a volume.
@@ -461,7 +427,7 @@ class BlockStorageCloudMixin:
         :raises: OpenStackCloudException on operation error.
         """
         kwargs = self._get_volume_kwargs(kwargs)
-        payload = {'volume_id': volume_id}
+        payload = {'volume_id': volume_id, 'force': force}
         payload.update(kwargs)
         snapshot = self.block_storage.create_snapshot(**payload)
         if wait:
