@@ -14,10 +14,8 @@
 
 import contextlib
 import fnmatch
-import functools
 import inspect
 import re
-import time
 import uuid
 
 from decorator import decorator
@@ -28,27 +26,6 @@ from openstack import _log
 from openstack.cloud import exc
 
 
-_decorated_methods = []
-
-
-def _make_unicode(input):
-    """Turn an input into unicode unconditionally
-
-    :param input: A unicode, string or other object
-    """
-    try:
-        if isinstance(input, unicode):
-            return input
-        if isinstance(input, str):
-            return input.decode('utf-8')
-        else:
-            # int, for example
-            return unicode(input)
-    except NameError:
-        # python3!
-        return str(input)
-
-
 def _dictify_resource(resource):
     if isinstance(resource, list):
         return [_dictify_resource(r) for r in resource]
@@ -80,6 +57,7 @@ def _filter_list(data, name_or_id, filters):
         OR
 
         A string containing a jmespath expression for further filtering.
+        Invalid filters will be ignored.
     """
     # The logger is openstack.cloud.fmmatch to allow a user/operator to
     # configure logging not to communicate about fnmatch misses
@@ -87,7 +65,7 @@ def _filter_list(data, name_or_id, filters):
     log = _log.setup_logging('openstack.fnmatch')
     if name_or_id:
         # name_or_id might already be unicode
-        name_or_id = _make_unicode(name_or_id)
+        name_or_id = str(name_or_id)
         identifier_matches = []
         bad_pattern = False
         try:
@@ -99,11 +77,12 @@ def _filter_list(data, name_or_id, filters):
             # search
             fn_reg = None
         for e in data:
-            e_id = _make_unicode(e.get('id', None))
-            e_name = _make_unicode(e.get('name', None))
+            e_id = str(e.get('id', None))
+            e_name = str(e.get('name', None))
 
-            if ((e_id and e_id == name_or_id)
-                    or (e_name and e_name == name_or_id)):
+            if (e_id and e_id == name_or_id) or (
+                e_name and e_name == name_or_id
+            ):
                 identifier_matches.append(e)
             else:
                 # Only try fnmatch if we don't match exactly
@@ -112,8 +91,9 @@ def _filter_list(data, name_or_id, filters):
                     # so that we log the bad pattern
                     bad_pattern = True
                     continue
-                if ((e_id and fn_reg.match(e_id))
-                        or (e_name and fn_reg.match(e_name))):
+                if (e_id and fn_reg.match(e_id)) or (
+                    e_name and fn_reg.match(e_name)
+                ):
                     identifier_matches.append(e)
         if not identifier_matches and bad_pattern:
             log.debug("Bad pattern passed to fnmatch", exc_info=True)
@@ -129,6 +109,17 @@ def _filter_list(data, name_or_id, filters):
         if not d:
             return False
         for key in f.keys():
+            if key not in d:
+                log.warning(
+                    "Invalid filter: %s is not an attribute of %s.%s",
+                    key,
+                    e.__class__.__module__,
+                    e.__class__.__qualname__,
+                )
+                # we intentionally skip this since the user was trying to
+                # filter on _something_, but we don't know what that
+                # _something_ was
+                raise AttributeError(key)
             if isinstance(f[key], dict):
                 if not _dict_filter(f[key], d.get(key, None)):
                     return False
@@ -138,15 +129,8 @@ def _filter_list(data, name_or_id, filters):
 
     filtered = []
     for e in data:
-        filtered.append(e)
-        for key in filters.keys():
-            if isinstance(filters[key], dict):
-                if not _dict_filter(filters[key], e.get(key, None)):
-                    filtered.pop()
-                    break
-            elif e.get(key, None) != filters[key]:
-                filtered.pop()
-                break
+        if _dict_filter(filters, e):
+            filtered.append(e)
     return filtered
 
 
@@ -166,14 +150,15 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
         Example:: "[?last_name==`Smith`] | [?other.gender]==`Female`]"
     """
 
-    # Sometimes in the control flow of shade, we already have an object
+    # Sometimes in the control flow of openstacksdk, we already have an object
     # fetched. Rather than then needing to pull the name or id out of that
     # object, pass it in here and rely on caching to prevent us from making
     # an additional call, it's simple enough to test to see if we got an
     # object and just short-circuit return it.
 
-    if (hasattr(name_or_id, 'id')
-            or (isinstance(name_or_id, dict) and 'id' in name_or_id)):
+    if hasattr(name_or_id, 'id') or (
+        isinstance(name_or_id, dict) and 'id' in name_or_id
+    ):
         return name_or_id
 
     # If a uuid is passed short-circuit it calling the
@@ -183,14 +168,18 @@ def _get_entity(cloud, resource, name_or_id, filters, **kwargs):
         if get_resource:
             return get_resource(name_or_id)
 
-    search = resource if callable(resource) else getattr(
-        cloud, 'search_%ss' % resource, None)
+    search = (
+        resource
+        if callable(resource)
+        else getattr(cloud, 'search_%ss' % resource, None)
+    )
     if search:
         entities = search(name_or_id, filters, **kwargs)
         if entities:
             if len(entities) > 1:
                 raise exc.OpenStackCloudException(
-                    "Multiple matches found for %s" % name_or_id)
+                    "Multiple matches found for %s" % name_or_id
+                )
             return entities[0]
     return None
 
@@ -230,54 +219,21 @@ def valid_kwargs(*valid_args):
             if k not in argspec.args[1:] and k not in valid_args:
                 raise TypeError(
                     "{f}() got an unexpected keyword argument "
-                    "'{arg}'".format(f=inspect.stack()[1][3], arg=k))
+                    "'{arg}'".format(f=inspect.stack()[1][3], arg=k)
+                )
         return func(*args, **kwargs)
+
     return func_wrapper
 
 
-def _func_wrap(f):
-    # NOTE(morgan): This extra wrapper is intended to eliminate ever
-    # passing a bound method to dogpile.cache's cache_on_arguments. In
-    # 0.7.0 and later it is impossible to pass bound methods to the
-    # decorator. This was introduced when utilizing the decorate module in
-    # lieu of a direct wrap implementation.
-    @functools.wraps(f)
-    def inner(*args, **kwargs):
-        return f(*args, **kwargs)
-    return inner
-
-
-def cache_on_arguments(*cache_on_args, **cache_on_kwargs):
-    _cache_name = cache_on_kwargs.pop('resource', None)
-
-    def _inner_cache_on_arguments(func):
-        def _cache_decorator(obj, *args, **kwargs):
-            the_method = obj._get_cache(_cache_name).cache_on_arguments(
-                *cache_on_args, **cache_on_kwargs)(
-                    _func_wrap(func.__get__(obj, type(obj))))
-            return the_method(*args, **kwargs)
-
-        def invalidate(obj, *args, **kwargs):
-            return obj._get_cache(
-                _cache_name).cache_on_arguments()(func).invalidate(
-                    *args, **kwargs)
-
-        _cache_decorator.invalidate = invalidate
-        _cache_decorator.func = func
-        _decorated_methods.append(func.__name__)
-
-        return _cache_decorator
-    return _inner_cache_on_arguments
-
-
 @contextlib.contextmanager
-def shade_exceptions(error_message=None):
-    """Context manager for dealing with shade exceptions.
+def openstacksdk_exceptions(error_message=None):
+    """Context manager for dealing with openstack exceptions.
 
     :param string error_message: String to use for the exception message
         content on non-OpenStackCloudExceptions.
 
-        Useful for avoiding wrapping shade OpenStackCloudException exceptions
+        Useful for avoiding wrapping OpenStackCloudException exceptions
         within themselves. Code called from within the context may throw such
         exceptions without having to catch and reraise them.
 
@@ -320,7 +276,8 @@ def safe_dict_min(key, data):
                 raise exc.OpenStackCloudException(
                     "Search for minimum value failed. "
                     "Value for {key} is not an integer: {value}".format(
-                        key=key, value=d[key])
+                        key=key, value=d[key]
+                    )
                 )
             if (min_value is None) or (val < min_value):
                 min_value = val
@@ -352,66 +309,14 @@ def safe_dict_max(key, data):
                 raise exc.OpenStackCloudException(
                     "Search for maximum value failed. "
                     "Value for {key} is not an integer: {value}".format(
-                        key=key, value=d[key])
+                        key=key, value=d[key]
+                    )
                 )
             if (max_value is None) or (val > max_value):
                 max_value = val
     return max_value
 
 
-def _call_client_and_retry(client, url, retry_on=None,
-                           call_retries=3, retry_wait=2,
-                           **kwargs):
-    """Method to provide retry operations.
-
-    Some APIs utilize HTTP errors on certain operations to indicate that
-    the resource is presently locked, and as such this mechanism provides
-    the ability to retry upon known error codes.
-
-    :param object client: The client method, such as:
-        ``self.baremetal_client.post``
-    :param string url: The URL to perform the operation upon.
-    :param integer retry_on: A list of error codes that can be retried on.
-        The method also supports a single integer to be
-        defined.
-    :param integer call_retries: The number of times to retry the call upon
-        the error code defined by the 'retry_on' parameter. Default: 3
-    :param integer retry_wait: The time in seconds to wait between retry
-        attempts. Default: 2
-
-    :returns: The object returned by the client call.
-    """
-
-    # NOTE(TheJulia): This method, as of this note, does not have direct
-    # unit tests, although is fairly well tested by the tests checking
-    # retry logic in test_baremetal_node.py.
-    log = _log.setup_logging('shade.http')
-
-    if isinstance(retry_on, int):
-        retry_on = [retry_on]
-
-    count = 0
-    while (count < call_retries):
-        count += 1
-        try:
-            ret_val = client(url, **kwargs)
-        except exc.OpenStackCloudHTTPError as e:
-            if (retry_on is not None
-                    and e.response.status_code in retry_on):
-                log.debug('Received retryable error %(err)s, waiting '
-                          '%(wait)s seconds to retry', {
-                              'err': e.response.status_code,
-                              'wait': retry_wait
-                          })
-                time.sleep(retry_wait)
-                continue
-            else:
-                raise
-        # Break out of the loop, since the loop should only continue
-        # when we encounter a known connection error.
-        return ret_val
-
-
 def parse_range(value):
     """Parse a numerical range string.
 
@@ -484,7 +389,8 @@ def range_filter(data, key, range_exp):
     # If parsing the range fails, it must be a bad value.
     if val_range is None:
         raise exc.OpenStackCloudException(
-            "Invalid range value: {value}".format(value=range_exp))
+            "Invalid range value: {value}".format(value=range_exp)
+        )
 
     op = val_range[0]
     if op:
@@ -523,9 +429,7 @@ def generate_patches_from_kwargs(operation, **kwargs):
     """
     patches = []
     for k, v in kwargs.items():
-        patch = {'op': operation,
-                 'value': v,
-                 'path': '/%s' % k}
+        patch = {'op': operation, 'value': v, 'path': '/%s' % k}
         patches.append(patch)
     return sorted(patches)
 
@@ -568,11 +472,13 @@ class FileSegment:
 
 
 def _format_uuid_string(string):
-    return (string.replace('urn:', '')
-                  .replace('uuid:', '')
-                  .strip('{}')
-                  .replace('-', '')
-                  .lower())
+    return (
+        string.replace('urn:', '')
+        .replace('uuid:', '')
+        .strip('{}')
+        .replace('-', '')
+        .lower()
+    )
 
 
 def _is_uuid_like(val):
