@@ -24,7 +24,7 @@ CONSOLE_TYPE_ACTION_MAPPING = {
     'xvpvnc': 'os-getVNCConsole',
     'spice-html5': 'os-getSPICEConsole',
     'rdp-html5': 'os-getRDPConsole',
-    'serial': 'os-getSerialConsole'
+    'serial': 'os-getSerialConsole',
 }
 
 
@@ -46,15 +46,33 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     _sentinel = object()
 
     _query_mapping = resource.QueryParameters(
-        "auto_disk_config", "availability_zone",
-        "created_at", "description", "flavor",
-        "hostname", "image", "kernel_id", "key_name",
-        "launch_index", "launched_at", "locked_by", "name",
-        "node", "power_state", "progress", "project_id", "ramdisk_id",
-        "reservation_id", "root_device_name",
-        "status", "task_state", "terminated_at", "user_id",
+        "auto_disk_config",
+        "availability_zone",
+        "created_at",
+        "description",
+        "flavor",
+        "hostname",
+        "image",
+        "kernel_id",
+        "key_name",
+        "launch_index",
+        "launched_at",
+        "locked_by",
+        "name",
+        "node",
+        "power_state",
+        "progress",
+        "project_id",
+        "ramdisk_id",
+        "reservation_id",
+        "root_device_name",
+        "status",
+        "task_state",
+        "terminated_at",
+        "user_id",
         "vm_state",
-        "sort_key", "sort_dir",
+        "sort_key",
+        "sort_dir",
         access_ipv4="access_ip_v4",
         access_ipv6="access_ip_v6",
         has_config_drive="config_drive",
@@ -67,7 +85,7 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         changes_before="changes-before",
         id="uuid",
         all_projects="all_tenants",
-        **tag.TagMixin._tag_query_parameters
+        **tag.TagMixin._tag_query_parameters,
     )
 
     _max_microversion = '2.91'
@@ -93,7 +111,8 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         aka='volumes',
         type=list,
         list_type=volume_attachment.VolumeAttachment,
-        default=[])
+        default=[],
+    )
     #: The name of the availability zone this server is a part of.
     availability_zone = resource.Body('OS-EXT-AZ:availability_zone')
     #: Enables fine grained control of the block device mapping for an
@@ -146,7 +165,6 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     #: routable ipv6 addresses, and to private_ipv4 if the Connection was
     #: created with private=True. Otherwise it will be set to public_ipv4.
     interface_ip = resource.Computed('interface_ip', default='')
-
     # The locked status of the server
     is_locked = resource.Body('locked', type=bool)
     #: The UUID of the kernel image when using an AMI. Will be null if not.
@@ -160,6 +178,8 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     launch_index = resource.Body('OS-EXT-SRV-ATTR:launch_index', type=int)
     #: The timestamp when the server was launched.
     launched_at = resource.Body('OS-SRV-USG:launched_at')
+    #: The reason the server was locked, if any.
+    locked_reason = resource.Body('locked_reason')
     #: The maximum number of servers to create.
     max_count = resource.Body('max_count')
     #: The minimum number of servers to create.
@@ -202,8 +222,9 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     scheduler_hints = resource.Body('OS-SCH-HNT:scheduler_hints', type=dict)
     #: A list of applicable security groups. Each group contains keys for
     #: description, name, id, and rules.
-    security_groups = resource.Body('security_groups',
-                                    type=list, list_type=dict)
+    security_groups = resource.Body(
+        'security_groups', type=list, list_type=dict
+    )
     #: The UUIDs of the server groups to which the server belongs.
     #: Currently this can contain at most one entry.
     server_groups = resource.Body('server_groups', type=list)
@@ -220,7 +241,8 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     #: A list of trusted certificate IDs, that were used during image
     #: signature verification to verify the signing certificate.
     trusted_image_certificates = resource.Body(
-        'trusted_image_certificates', type=list)
+        'trusted_image_certificates', type=list
+    )
     #: Timestamp of when this server was last updated.
     updated_at = resource.Body('updated')
     #: Configuration information or scripts to use upon launch.
@@ -231,11 +253,18 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
     #: The VM state of this server.
     vm_state = resource.Body('OS-EXT-STS:vm_state')
 
-    def _prepare_request(self, requires_id=True, prepend_key=True,
-                         base_path=None, **kwargs):
-        request = super(Server, self)._prepare_request(requires_id=requires_id,
-                                                       prepend_key=prepend_key,
-                                                       base_path=base_path)
+    def _prepare_request(
+        self,
+        requires_id=True,
+        prepend_key=True,
+        base_path=None,
+        **kwargs,
+    ):
+        request = super(Server, self)._prepare_request(
+            requires_id=requires_id,
+            prepend_key=prepend_key,
+            base_path=base_path,
+        )
 
         server_body = request.body[self.resource_key]
 
@@ -286,13 +315,22 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         exceptions.raise_from_response(response)
         return response
 
-    def change_password(self, session, new_password):
-        """Change the administrator password to the given password."""
-        body = {'changePassword': {'adminPass': new_password}}
+    def change_password(self, session, password):
+        """Change the administrator password to the given password.
+
+        :param session: The session to use for making this request.
+        :param password: The new password.
+        :returns: None
+        """
+        body = {'changePassword': {'adminPass': password}}
         self._action(session, body)
 
     def get_password(self, session):
-        """Get the encrypted administrator password."""
+        """Get the encrypted administrator password.
+
+        :param session: The session to use for making this request.
+        :returns: The encrypted administrator password.
+        """
         url = utils.urljoin(Server.base_path, self.id, 'os-server-password')
 
         response = session.get(url)
@@ -302,23 +340,57 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         return data.get('password')
 
     def reboot(self, session, reboot_type):
-        """Reboot server where reboot_type might be 'SOFT' or 'HARD'."""
+        """Reboot server where reboot_type might be 'SOFT' or 'HARD'.
+
+        :param session: The session to use for making this request.
+        :param reboot_type: The type of reboot. One of: ``SOFT``, ``HARD``.
+        :returns: None
+        """
         body = {'reboot': {'type': reboot_type}}
         self._action(session, body)
 
     def force_delete(self, session):
-        """Force delete a server."""
+        """Force delete the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {'forceDelete': None}
         self._action(session, body)
 
-    def rebuild(self, session, image, name=None, admin_password=None,
-                preserve_ephemeral=None,
-                access_ipv4=None, access_ipv6=None,
-                metadata=None, user_data=None, key_name=None):
-        """Rebuild the server with the given arguments."""
-        action = {
-            'imageRef': resource.Resource._get_id(image)
-        }
+    def rebuild(
+        self,
+        session,
+        image,
+        name=None,
+        admin_password=None,
+        preserve_ephemeral=None,
+        access_ipv4=None,
+        access_ipv6=None,
+        metadata=None,
+        user_data=None,
+        key_name=None,
+    ):
+        """Rebuild the server with the given arguments.
+
+        :param session: The session to use for making this request.
+        :param image: The image to rebuild to. Either an ID or a
+            :class:`~openstack.image.v1.image.Image` instance.
+        :param name: A name to set on the rebuilt server. (Optional)
+        :param admin_password: An admin password to set on the rebuilt server.
+            (Optional)
+        :param preserve_ephemeral: Whether to preserve the ephemeral drive
+            during the rebuild. (Optional)
+        :param access_ipv4: An IPv4 address that will be used to access the
+            rebuilt server. (Optional)
+        :param access_ipv6: An IPv6 address that will be used to access the
+            rebuilt server. (Optional)
+        :param metadata: Metadata to set on the updated server. (Optional)
+        :param user_data: User data to set on the updated server. (Optional)
+        :param key_name: A key name to set on the updated server. (Optional)
+        :returns: The updated server.
+        """
+        action = {'imageRef': resource.Resource._get_id(image)}
         if preserve_ephemeral is not None:
             action['preserve_ephemeral'] = preserve_ephemeral
         if name is not None:
@@ -342,22 +414,41 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         return self
 
     def resize(self, session, flavor):
-        """Resize server to flavor reference."""
+        """Resize server to flavor reference.
+
+        :param session: The session to use for making this request.
+        :param flavor: The server to resize to.
+        :returns: None
+        """
         body = {'resize': {'flavorRef': flavor}}
         self._action(session, body)
 
     def confirm_resize(self, session):
-        """Confirm the resize of the server."""
+        """Confirm the resize of the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {'confirmResize': None}
         self._action(session, body)
 
     def revert_resize(self, session):
-        """Revert the resize of the server."""
+        """Revert the resize of the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {'revertResize': None}
         self._action(session, body)
 
     def create_image(self, session, name, metadata=None):
-        """Create image from server."""
+        """Create image from server.
+
+        :param session: The session to use for making this request.
+        :param name: The name to use for the created image.
+        :param metadata: Metadata to set on the created image. (Optional)
+        :returns: None
+        """
         action = {'name': name}
         if metadata is not None:
             action['metadata'] = metadata
@@ -397,62 +488,152 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         return image_id
 
     def add_security_group(self, session, security_group_name):
+        """Add a security group to the server.
+
+        :param session: The session to use for making this request.
+        :param security_group_name: The security group to add to the server.
+        :returns: None
+        """
         body = {"addSecurityGroup": {"name": security_group_name}}
         self._action(session, body)
 
     def remove_security_group(self, session, security_group_name):
+        """Remove a security group from the server.
+
+        :param session: The session to use for making this request.
+        :param security_group_name: The security group to remove from the
+            server.
+        :returns: None
+        """
         body = {"removeSecurityGroup": {"name": security_group_name}}
         self._action(session, body)
 
     def reset_state(self, session, state):
+        """Reset server state.
+
+        This is admin-only by default.
+
+        :param session: The session to use for making this request.
+        :param state: The state to set on the server.
+        :returns: None
+        """
         body = {"os-resetState": {"state": state}}
         self._action(session, body)
 
     def add_fixed_ip(self, session, network_id):
+        """Add a fixed IP to the server.
+
+        This is effectively an alias for adding a network.
+
+        :param session: The session to use for making this request.
+        :param network_id: The network to connect the server to.
+        :returns: None
+        """
         body = {"addFixedIp": {"networkId": network_id}}
         self._action(session, body)
 
     def remove_fixed_ip(self, session, address):
+        """Remove a fixed IP from the server.
+
+        This is effectively an alias from removing a port from the server.
+
+        :param session: The session to use for making this request.
+        :param network_id: The address to remove from the server.
+        :returns: None
+        """
         body = {"removeFixedIp": {"address": address}}
         self._action(session, body)
 
     def add_floating_ip(self, session, address, fixed_address=None):
+        """Add a floating IP to the server.
+
+        :param session: The session to use for making this request.
+        :param address: The floating IP address to associate with the server.
+        :param fixed_address: A fixed IP address with which to associated the
+            floating IP. (Optional)
+        :returns: None
+        """
         body = {"addFloatingIp": {"address": address}}
         if fixed_address is not None:
             body['addFloatingIp']['fixed_address'] = fixed_address
         self._action(session, body)
 
     def remove_floating_ip(self, session, address):
+        """Remove a floating IP from the server.
+
+        :param session: The session to use for making this request.
+        :param address: The floating IP address to disassociate from the
+            server.
+        :returns: None
+        """
         body = {"removeFloatingIp": {"address": address}}
         self._action(session, body)
 
     def backup(self, session, name, backup_type, rotation):
+        """Create a backup of the server.
+
+        :param session: The session to use for making this request.
+        :param name: The name to use for the backup image.
+        :param backup_type: The type of backup. The value and meaning of this
+            atribute is user-defined and can be used to separate backups of
+            different types. For example, this could be used to distinguish
+            between ``daily`` and ``weekly`` backups.
+        :param rotation: The number of backups to retain. All images older than
+            the rotation'th image will be deleted.
+        :returns: None
+        """
         body = {
             "createBackup": {
                 "name": name,
                 "backup_type": backup_type,
-                "rotation": rotation
+                "rotation": rotation,
             }
         }
         self._action(session, body)
 
     def pause(self, session):
+        """Pause the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"pause": None}
         self._action(session, body)
 
     def unpause(self, session):
+        """Unpause the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"unpause": None}
         self._action(session, body)
 
     def suspend(self, session):
+        """Suspend the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"suspend": None}
         self._action(session, body)
 
     def resume(self, session):
+        """Resume the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"resume": None}
         self._action(session, body)
 
     def lock(self, session, locked_reason=None):
+        """Lock the server.
+
+        :param session: The session to use for making this request.
+        :param locked_reason: The reason for locking the server.
+        :returns: None
+        """
         body = {"lock": None}
         if locked_reason is not None:
             body["lock"] = {
@@ -461,10 +642,26 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         self._action(session, body)
 
     def unlock(self, session):
+        """Unlock the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"unlock": None}
         self._action(session, body)
 
     def rescue(self, session, admin_pass=None, image_ref=None):
+        """Rescue the server.
+
+        This is admin-only by default.
+
+        :param session: The session to use for making this request.
+        :param admin_pass: A new admin password to set on the rescued server.
+            (Optional)
+        :param image_ref: The image to use when rescuing the server. If not
+            provided, the server will use the existing image. (Optional)
+        :returns: None
+        """
         body = {"rescue": {}}
         if admin_pass is not None:
             body["rescue"]["adminPass"] = admin_pass
@@ -473,10 +670,26 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         self._action(session, body)
 
     def unrescue(self, session):
+        """Unrescue the server.
+
+        This is admin-only by default.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"unrescue": None}
         self._action(session, body)
 
     def evacuate(self, session, host=None, admin_pass=None, force=None):
+        """Evacuate the server.
+
+        :param session: The session to use for making this request.
+        :param host: The host to evacuate the instance to. (Optional)
+        :param admin_pass: The admin password to set on the evacuated instance.
+            (Optional)
+        :param force: Whether to force evacuation.
+        :returns: None
+        """
         body = {"evacuate": {}}
         if host is not None:
             body["evacuate"]["host"] = host
@@ -487,25 +700,57 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         self._action(session, body)
 
     def start(self, session):
+        """Start the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"os-start": None}
         self._action(session, body)
 
     def stop(self, session):
+        """Stop the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"os-stop": None}
         self._action(session, body)
 
     def restore(self, session):
+        """Restore the server.
+
+        This is only supported if the server is soft-deleted. This is
+        cloud-specific.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"restore": None}
         self._action(session, body)
 
     def shelve(self, session):
+        """Shelve the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"shelve": None}
         self._action(session, body)
 
-    def unshelve(self, session, availability_zone=_sentinel, host=None):
-        """
-        Unshelve -- Unshelve the server.
+    def shelve_offload(self, session):
+        """Shelve-offload the server.
 
+        :param session: The session to use for making this request.
+        :returns: None
+        """
+        body = {"shelveOffload": None}
+        self._action(session, body)
+
+    def unshelve(self, session, availability_zone=_sentinel, host=None):
+        """Unshelve the server.
+
+        :param session: The session to use for making this request.
         :param availability_zone: If specified the instance will be unshelved
             to the availability_zone.
             If None is passed the instance defined availability_zone is unpin
@@ -525,14 +770,31 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         self._action(session, body)
 
     def migrate(self, session):
+        """Migrate the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"migrate": None}
         self._action(session, body)
 
     def trigger_crash_dump(self, session):
+        """Trigger a crash dump for the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         body = {"trigger_crash_dump": None}
         self._action(session, body)
 
     def get_console_output(self, session, length=None):
+        """Get console output for the server.
+
+        :param session: The session to use for making this request.
+        :param length: The max length of the console output to return.
+            (Optional)
+        :returns: None
+        """
         body = {"os-getConsoleOutput": {}}
         if length is not None:
             body["os-getConsoleOutput"]["length"] = length
@@ -540,6 +802,14 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         return resp.json()
 
     def get_console_url(self, session, console_type):
+        """Get the console URL for the server.
+
+        :param session: The session to use for making this request.
+        :param console_type: The type of console to return. This is
+            cloud-specific. One of: ``novnc``, ``xvpvnc``, ``spice-html5``,
+            ``rdp-html5``, ``serial``.
+        :returns: None
+        """
         action = CONSOLE_TYPE_ACTION_MAPPING.get(console_type)
         if not action:
             raise ValueError("Unsupported console type %s" % console_type)
@@ -547,24 +817,47 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         resp = self._action(session, body)
         return resp.json().get('console')
 
-    def live_migrate(self, session, host, force, block_migration,
-                     disk_over_commit=False):
+    def live_migrate(
+        self,
+        session,
+        host,
+        force,
+        block_migration,
+        disk_over_commit=False,
+    ):
+        """Live migrate the server.
+
+        :param session: The session to use for making this request.
+        :param host: The host to live migrate the server to. (Optional)
+        :param force: Whether to force the migration. (Optional)
+        :param block_migration: Whether to do block migration. One of:
+            ``True``, ``False``, ``'auto'``. (Optional)
+        :param disk_over_commit: Whether to allow disk over-commit on the
+            destination host. (Optional)
+        :returns: None
+        """
         if utils.supports_microversion(session, '2.30'):
             return self._live_migrate_30(
-                session, host,
-                force=force,
-                block_migration=block_migration)
-        elif utils.supports_microversion(session, '2.25'):
-            return self._live_migrate_25(
-                session, host,
-                force=force,
-                block_migration=block_migration)
-        else:
-            return self._live_migrate(
-                session, host,
+                session,
+                host,
                 force=force,
                 block_migration=block_migration,
-                disk_over_commit=disk_over_commit)
+            )
+        elif utils.supports_microversion(session, '2.25'):
+            return self._live_migrate_25(
+                session,
+                host,
+                force=force,
+                block_migration=block_migration,
+            )
+        else:
+            return self._live_migrate(
+                session,
+                host,
+                force=force,
+                block_migration=block_migration,
+                disk_over_commit=disk_over_commit,
+            )
 
     def _live_migrate_30(self, session, host, force, block_migration):
         microversion = '2.30'
@@ -577,7 +870,10 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
             if force:
                 body['force'] = force
         self._action(
-            session, {'os-migrateLive': body}, microversion=microversion)
+            session,
+            {'os-migrateLive': body},
+            microversion=microversion,
+        )
 
     def _live_migrate_25(self, session, host, force, block_migration):
         microversion = '2.25'
@@ -594,12 +890,22 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
                     " possible to disable. It is recommended to not use 'host'"
                     " at all on this cloud as it is inherently unsafe, but if"
                     " it is unavoidable, please supply 'force=True' so that it"
-                    " is clear you understand the risks.")
+                    " is clear you understand the risks."
+                )
         self._action(
-            session, {'os-migrateLive': body}, microversion=microversion)
+            session,
+            {'os-migrateLive': body},
+            microversion=microversion,
+        )
 
-    def _live_migrate(self, session, host, force, block_migration,
-                      disk_over_commit):
+    def _live_migrate(
+        self,
+        session,
+        host,
+        force,
+        block_migration,
+        disk_over_commit,
+    ):
         microversion = None
         body = {
             'host': None,
@@ -607,7 +913,8 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
         if block_migration == 'auto':
             raise ValueError(
                 "Live migration on this cloud does not support 'auto' as"
-                " a parameter to block_migration, but only True and False.")
+                " a parameter to block_migration, but only True and False."
+            )
         body['block_migration'] = block_migration or False
         body['disk_over_commit'] = disk_over_commit or False
         if host:
@@ -619,11 +926,20 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
                     " possible to disable. It is recommended to not use 'host'"
                     " at all on this cloud as it is inherently unsafe, but if"
                     " it is unavoidable, please supply 'force=True' so that it"
-                    " is clear you understand the risks.")
+                    " is clear you understand the risks."
+                )
         self._action(
-            session, {'os-migrateLive': body}, microversion=microversion)
+            session,
+            {'os-migrateLive': body},
+            microversion=microversion,
+        )
 
     def fetch_topology(self, session):
+        """Fetch the topology information for the server.
+
+        :param session: The session to use for making this request.
+        :returns: None
+        """
         utils.require_microversion(session, 2.78)
 
         url = utils.urljoin(Server.base_path, self.id, 'topology')
@@ -638,10 +954,10 @@ class Server(resource.Resource, metadata.MetadataMixin, tag.TagMixin):
             pass
 
     def fetch_security_groups(self, session):
-        """Fetch security groups of a server.
+        """Fetch security groups of the server.
 
+        :param session: The session to use for making this request.
         :returns: Updated Server instance.
-
         """
         url = utils.urljoin(Server.base_path, self.id, 'os-security-groups')
 
