@@ -18,6 +18,7 @@ Exception definitions.
 
 import json
 import re
+import typing as ty
 
 from requests import exceptions as _rex
 
@@ -57,6 +58,8 @@ class InvalidRequest(SDKException):
 
 
 class HttpException(SDKException, _rex.HTTPError):
+    """The base exception for all HTTP error responses."""
+
     def __init__(
         self,
         message='Error',
@@ -119,26 +122,18 @@ class HttpException(SDKException, _rex.HTTPError):
 class BadRequestException(HttpException):
     """HTTP 400 Bad Request."""
 
-    pass
-
 
 class ForbiddenException(HttpException):
     """HTTP 403 Forbidden Request."""
 
-    pass
-
 
 class ConflictException(HttpException):
     """HTTP 409 Conflict."""
 
-    pass
-
 
 class PreconditionFailedException(HttpException):
     """HTTP 412 Precondition Failed."""
 
-    pass
-
 
 class MethodNotSupported(SDKException):
     """The resource does not support this operation type."""
@@ -161,13 +156,9 @@ class MethodNotSupported(SDKException):
 class DuplicateResource(SDKException):
     """More than one resource exists with that name."""
 
-    pass
-
 
 class ResourceNotFound(HttpException):
-    """No resource exists with that name or id."""
-
-    pass
+    """No resource exists with that name or ID."""
 
 
 NotFoundException = ResourceNotFound
@@ -176,20 +167,14 @@ NotFoundException = ResourceNotFound
 class ResourceTimeout(SDKException):
     """Timeout waiting for resource."""
 
-    pass
-
 
 class ResourceFailure(SDKException):
     """General resource failure."""
 
-    pass
-
 
 class InvalidResourceQuery(SDKException):
     """Invalid query params for resource."""
 
-    pass
-
 
 def _extract_message(obj):
     if isinstance(obj, dict):
@@ -214,6 +199,7 @@ def raise_from_response(response, error_message=None):
     if response.status_code < 400:
         return
 
+    cls: ty.Type[SDKException]
     if response.status_code == 400:
         cls = BadRequestException
     elif response.status_code == 403:
@@ -246,13 +232,14 @@ def raise_from_response(response, error_message=None):
         except Exception:
             details = response.text
     elif response.content and 'text/html' in content_type:
-        # Split the lines, strip whitespace and inline HTML from the response.
-        details = [
-            re.sub(r'<.+?>', '', i.strip()) for i in response.text.splitlines()
-        ]
-        details = list(set([msg for msg in details if msg]))
+        messages = []
+        for line in response.text.splitlines():
+            message = re.sub(r'<.+?>', '', line.strip())
+            if message not in messages:
+                messages.append(message)
+
         # Return joined string separated by colons.
-        details = ': '.join(details)
+        details = ': '.join(messages)
 
     if not details:
         details = response.reason if response.reason else response.text
@@ -281,10 +268,6 @@ class ValidationException(SDKException):
     """Validation failed for resource."""
 
 
-class TaskManagerStopped(SDKException):
-    """Operations were attempted on a stopped TaskManager."""
-
-
 class ServiceDisabledException(ConfigException):
     """This service is disabled for reasons."""
 
