@@ -19,6 +19,8 @@ from openstack.image.v2 import cache as _cache
 from openstack.image.v2 import image as _image
 from openstack.image.v2 import member as _member
 from openstack.image.v2 import metadef_namespace as _metadef_namespace
+from openstack.image.v2 import metadef_object as _metadef_object
+from openstack.image.v2 import metadef_property as _metadef_property
 from openstack.image.v2 import metadef_resource_type as _metadef_resource_type
 from openstack.image.v2 import metadef_schema as _metadef_schema
 from openstack.image.v2 import schema as _schema
@@ -340,8 +342,6 @@ class Proxy(proxy.Proxy):
             image_kwargs['name'] = name
             image = self._create(_image.Image, **image_kwargs)
 
-        self._connection._get_cache(None).invalidate()
-
         return image
 
     def import_image(
@@ -733,7 +733,6 @@ class Proxy(proxy.Proxy):
         }
 
         glance_task = self.create_task(**task_args)
-        self._connection.list_images.invalidate(self)
         if wait:
             start = time.time()
 
@@ -770,7 +769,6 @@ class Proxy(proxy.Proxy):
                 # Clean up after ourselves. The object we created is not
                 # needed after the import is done.
                 self._connection.delete_object(container, name)
-                self._connection.list_images.invalidate(self)
             return image
         else:
             return glance_task
@@ -784,7 +782,7 @@ class Proxy(proxy.Proxy):
         *,
         stream=False,
         output=None,
-        chunk_size=1024,
+        chunk_size=1024 * 1024,
     ):
         """Download an image
 
@@ -808,7 +806,7 @@ class Proxy(proxy.Proxy):
             When ``False``, return the entire contents of the response.
         :param output: Either a file object or a path to store data into.
         :param int chunk_size: size in bytes to read from the wire and buffer
-            at one time. Defaults to 1024
+            at one time. Defaults to 1024 * 1024 = 1 MiB
 
         :returns: When output is not given - the bytes comprising the given
             Image when stream is False, otherwise a :class:`requests.Response`
@@ -963,8 +961,6 @@ class Proxy(proxy.Proxy):
 
         self.update_image(image, **img_props)
 
-        self._connection.list_images.invalidate(self._connection)
-
         return True
 
     def add_tag(self, image, tag):
@@ -1205,6 +1201,117 @@ class Proxy(proxy.Proxy):
             **attrs,
         )
 
+    # ====== METADEF OBJECT ======
+    def create_metadef_object(self, namespace, **attrs):
+        """Create a new object from namespace
+
+        :param namespace: The value can be either the name of a metadef
+            namespace or a
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance.
+        :param dict attrs: Keyword arguments which will be used to create
+            a :class:`~openstack.image.v2.metadef_object.MetadefObject`,
+            comprised of the properties on the Metadef object class.
+
+        :returns: A metadef namespace
+        :rtype: :class:`~openstack.image.v2.metadef_object.MetadefObject`
+        """
+        namespace_name = resource.Resource._get_id(namespace)
+        return self._create(
+            _metadef_object.MetadefObject,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def get_metadef_object(self, metadef_object, namespace):
+        """Get a single metadef object
+
+        :param metadef_object: The value can be the ID of a metadef_object
+            or a
+            :class:`~openstack.image.v2.metadef_object.MetadefObject`
+            instance.
+        :param namespace: The value can be either the name of a metadef
+            namespace or a
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance.
+        :returns: One :class:`~openstack.image.v2.metadef_object.MetadefObject`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        object_name = resource.Resource._get_id(metadef_object)
+        namespace_name = resource.Resource._get_id(namespace)
+        return self._get(
+            _metadef_object.MetadefObject,
+            namespace_name=namespace_name,
+            name=object_name,
+        )
+
+    def metadef_objects(self, namespace):
+        """Get metadef object list of the namespace
+
+        :param namespace: The value can be either the name of a metadef
+            namespace or a
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance.
+
+        :returns: One :class:`~openstack.image.v2.metadef_object.MetadefObject`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        namespace_name = resource.Resource._get_id(namespace)
+        return self._list(
+            _metadef_object.MetadefObject,
+            namespace_name=namespace_name,
+        )
+
+    def update_metadef_object(self, metadef_object, namespace, **attrs):
+        """Update a single metadef object
+
+        :param metadef_object: The value can be the ID of a metadef_object or a
+            :class:`~openstack.image.v2.metadef_object.MetadefObject` instance.
+        :param namespace: The value can be either the name of a metadef
+            namespace or a
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance.
+        :param dict attrs: Keyword arguments which will be used to update
+            a :class:`~openstack.image.v2.metadef_object.MetadefObject`
+
+        :returns: One :class:`~openstack.image.v2.metadef_object.MetadefObject`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        namespace_name = resource.Resource._get_id(namespace)
+        return self._update(
+            _metadef_object.MetadefObject,
+            metadef_object,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def delete_metadef_object(self, metadef_object, namespace, **attrs):
+        """Removes a single metadef object
+
+        :param metadef_object: The value can be the ID of a metadef_object or a
+            :class:`~openstack.image.v2.metadef_object.MetadefObject` instance.
+        :param namespace: The value can be either the name of a metadef
+            namespace or a
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance.
+        :param dict attrs: Keyword arguments which will be used to update
+            a :class:`~openstack.image.v2.metadef_object.MetadefObject`
+
+        :returns: ``None``
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        namespace_name = resource.Resource._get_id(namespace)
+        return self._delete(
+            _metadef_object.MetadefObject,
+            metadef_object,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
     # ====== METADEF RESOURCE TYPES ======
     def metadef_resource_types(self, **query):
         """Return a generator of metadef resource types
@@ -1213,7 +1320,7 @@ class Proxy(proxy.Proxy):
         :rtype:
             :class:`~openstack.image.v2.metadef_resource_type.MetadefResourceType`
         :raises: :class:`~openstack.exceptions.ResourceNotFound`
-                when no resource can be found.
+            when no resource can be found.
         """
         return self._list(_metadef_resource_type.MetadefResourceType, **query)
 
@@ -1291,6 +1398,132 @@ class Proxy(proxy.Proxy):
             **query,
         )
 
+    # ====== METADEF PROPERTY ======
+    def create_metadef_property(self, metadef_namespace, **attrs):
+        """Create a metadef property
+
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_property.MetadefNamespace`
+            instance
+        :param attrs: The attributes to create on the metadef property
+            represented by ``metadef_property``.
+
+        :returns: The created metadef property
+        :rtype: :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._create(
+            _metadef_property.MetadefProperty,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def update_metadef_property(
+        self, metadef_property, metadef_namespace, **attrs
+    ):
+        """Update a metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance.
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param attrs: The attributes to update on the metadef property
+            represented by ``metadef_property``.
+
+        :returns: The updated metadef property
+        :rtype: :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        metadef_property = resource.Resource._get_id(metadef_property)
+        return self._update(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            **attrs,
+        )
+
+    def delete_metadef_property(
+        self, metadef_property, metadef_namespace, ignore_missing=True
+    ):
+        """Delete a metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param bool ignore_missing: When set to
+            ``False`` :class:`~openstack.exceptions.ResourceNotFound` will be
+            raised when the instance does not exist. When set to ``True``,
+            no exception will be set when attempting to delete a nonexistent
+            instance.
+
+        :returns: ``None``
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        metadef_property = resource.Resource._get_id(metadef_property)
+        return self._delete(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            ignore_missing=ignore_missing,
+        )
+
+    def metadef_properties(self, metadef_namespace, **query):
+        """Return a generator of metadef properties
+
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+        :param kwargs query: Optional query parameters to be sent to limit
+            the resources being returned.
+
+        :returns: A generator of property objects
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._list(
+            _metadef_property.MetadefProperty,
+            requires_id=False,
+            namespace_name=namespace_name,
+            **query,
+        )
+
+    def get_metadef_property(
+        self, metadef_property, metadef_namespace, **query
+    ):
+        """Get a single metadef property
+
+        :param metadef_property: The value can be either the name of metadef
+            property or an
+            :class:`~openstack.image.v2.metadef_property.MetadefProperty`
+            instance.
+        :param metadef_namespace: The value can be either the name of metadef
+            namespace or an
+            :class:`~openstack.image.v2.metadef_namespace.MetadefNamespace`
+            instance
+
+        :returns: One
+            :class:`~~openstack.image.v2.metadef_property.MetadefProperty`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound` when no
+            resource can be found.
+        """
+        namespace_name = resource.Resource._get_id(metadef_namespace)
+        return self._get(
+            _metadef_property.MetadefProperty,
+            metadef_property,
+            namespace_name=namespace_name,
+            **query,
+        )
+
     # ====== SCHEMAS ======
     def get_images_schema(self):
         """Get images schema
@@ -1621,7 +1854,7 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.image.v2.service_info.Store`
         """
         if details:
-            query['base_path'] = utils.urljoin(_si.Store, 'details')
+            query['base_path'] = utils.urljoin(_si.Store.base_path, 'detail')
         return self._list(_si.Store, **query)
 
     # ====== IMPORTS ======
