@@ -56,5 +56,10 @@ class Host(resource.Resource):
     failover_segment_id = resource.Body("failover_segment_id")
 
     _query_mapping = resource.QueryParameters(
-        "sort_key", "sort_dir", failover_segment_id="failover_segment_id",
-        type="type", on_maintenance="on_maintenance", reserved="reserved")
+        "sort_key",
+        "sort_dir",
+        failover_segment_id="failover_segment_id",
+        type="type",
+        on_maintenance="on_maintenance",
+        reserved="reserved",
+    )
