@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource
 
 
@@ -18,22 +17,32 @@ class MeteringLabel(resource.Resource):
     resource_key = 'metering_label'
     resources_key = 'metering_labels'
     base_path = '/metering/metering-labels'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
+    _query_mapping = resource.QueryParameters(
+        'description',
+        'name',
+        'project_id',
+        is_shared='shared',
+    )
+
     # Properties
     #: Description of the metering label.
-    description = resource.prop('description')
+    description = resource.Body('description')
     #: Name of the metering label.
-    name = resource.prop('name')
+    name = resource.Body('name')
     #: The ID of the project this metering label is associated with.
-    project_id = resource.prop('tenant_id')
+    project_id = resource.Body('project_id', alias='tenant_id')
+    #: Tenant_id (deprecated attribute).
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: Indicates whether this label is shared across all tenants.
     #: *Type: bool*
-    is_shared = resource.prop('shared', type=bool)
+    is_shared = resource.Body('shared', type=bool)
