@@ -18,6 +18,8 @@ class RBACPolicy(resource.Resource):
     resources_key = 'rbac_policies'
     base_path = '/rbac-policies'
 
+    _allow_unknown_attrs_in_body = True
+
     # capabilities
     allow_create = True
     allow_fetch = True
@@ -26,8 +28,12 @@ class RBACPolicy(resource.Resource):
     allow_list = True
 
     _query_mapping = resource.QueryParameters(
-        'action', 'object_id', 'object_type', 'project_id',
+        'action',
+        'object_id',
+        'object_type',
+        'project_id',
         'target_project_id',
+        target_project_id='target_tenant',
     )
 
     # Properties
@@ -36,7 +42,9 @@ class RBACPolicy(resource.Resource):
     #: The ID of the project this RBAC will be enforced.
     target_project_id = resource.Body('target_tenant')
     #: The owner project ID.
-    project_id = resource.Body('tenant_id')
+    project_id = resource.Body('project_id', alias='tenant_id')
+    #: Tenant_id (deprecated attribute).
+    tenant_id = resource.Body('tenant_id', deprecated=True)
     #: Type of the object that this RBAC policy affects.
     object_type = resource.Body('object_type')
     #: Action for the RBAC policy.
