@@ -11,11 +11,7 @@
 # under the License.
 
 import functools
-from typing import Generator
-from typing import Generic
-from typing import Optional
-from typing import Type
-from typing import TypeVar
+import typing as ty
 import urllib
 from urllib.parse import urlparse
 
@@ -24,7 +20,7 @@ try:
 
     JSONDecodeError = simplejson.scanner.JSONDecodeError
 except ImportError:
-    JSONDecodeError = ValueError
+    JSONDecodeError = ValueError  # type: ignore
 import iso8601
 import jmespath
 from keystoneauth1 import adapter
@@ -33,7 +29,8 @@ from openstack import _log
 from openstack import exceptions
 from openstack import resource
 
-T = TypeVar('T')
+
+ResourceType = ty.TypeVar('ResourceType', bound=resource.Resource)
 
 
 # The _check_resource decorator is used on Proxy methods to ensure that
@@ -74,7 +71,7 @@ def normalize_metric_name(name):
     return name
 
 
-class Proxy(adapter.Adapter, Generic[T]):
+class Proxy(adapter.Adapter):
     """Represents a service."""
 
     retriable_status_codes = None
@@ -84,7 +81,7 @@ class Proxy(adapter.Adapter, Generic[T]):
     ``<service-type>_status_code_retries``.
     """
 
-    _resource_registry = dict()
+    _resource_registry: ty.Dict[str, ty.Type[resource.Resource]] = {}
     """Registry of the supported resourses.
 
     Dictionary of resource names (key) types (value).
@@ -100,7 +97,7 @@ class Proxy(adapter.Adapter, Generic[T]):
         influxdb_config=None,
         influxdb_client=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         # NOTE(dtantsur): keystoneauth defaults retriable_status_codes to None,
         # override it with a class-level value.
@@ -144,7 +141,7 @@ class Proxy(adapter.Adapter, Generic[T]):
         connect_retries=1,
         global_request_id=None,
         *args,
-        **kwargs
+        **kwargs,
     ):
         conn = self._get_connection()
         if not global_request_id:
@@ -180,7 +177,7 @@ class Proxy(adapter.Adapter, Generic[T]):
                             connect_retries=connect_retries,
                             raise_exc=raise_exc,
                             global_request_id=global_request_id,
-                            **kwargs
+                            **kwargs,
                         ),
                     ),
                     expiration_time=expiration_time,
@@ -196,7 +193,7 @@ class Proxy(adapter.Adapter, Generic[T]):
                     connect_retries=connect_retries,
                     raise_exc=raise_exc,
                     global_request_id=global_request_id,
-                    **kwargs
+                    **kwargs,
                 )
 
             for h in response.history:
@@ -211,6 +208,7 @@ class Proxy(adapter.Adapter, Generic[T]):
             self._report_stats(None, url, method, e)
             raise
 
+    # TODO(stephenfin): service_type is unused and should be dropped
     @functools.lru_cache(maxsize=256)
     def _extract_name(self, url, service_type=None, project_id=None):
         """Produce a key name to use in logging/metrics from the URL path.
@@ -420,12 +418,6 @@ class Proxy(adapter.Adapter, Generic[T]):
         except Exception:
             self.log.exception('Error writing statistics to InfluxDB')
 
-    def _version_matches(self, version):
-        api_version = self.get_api_major_version()
-        if api_version:
-            return api_version[0] == version
-        return False
-
     def _get_connection(self):
         """Get the Connection object associated with this Proxy.
 
@@ -437,7 +429,9 @@ class Proxy(adapter.Adapter, Generic[T]):
             self, '_connection', getattr(self.session, '_sdk_connection', None)
         )
 
-    def _get_resource(self, resource_type: Type[T], value, **attrs) -> T:
+    def _get_resource(
+        self, resource_type: ty.Type[ResourceType], value, **attrs
+    ) -> ResourceType:
         """Get a resource object to work on
 
         :param resource_type: The type of resource to operate on. This should
@@ -484,8 +478,12 @@ class Proxy(adapter.Adapter, Generic[T]):
         return value
 
     def _find(
-        self, resource_type: Type[T], name_or_id, ignore_missing=True, **attrs
-    ) -> Optional[T]:
+        self,
+        resource_type: ty.Type[ResourceType],
+        name_or_id,
+        ignore_missing=True,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
         """Find a resource
 
         :param name_or_id: The name or ID of a resource to find.
@@ -506,8 +504,12 @@ class Proxy(adapter.Adapter, Generic[T]):
 
     @_check_resource(strict=False)
     def _delete(
-        self, resource_type: Type[T], value, ignore_missing=True, **attrs
-    ):
+        self,
+        resource_type: ty.Type[ResourceType],
+        value,
+        ignore_missing=True,
+        **attrs,
+    ) -> ty.Optional[ResourceType]:
         """Delete a resource
 
         :param resource_type: The type of resource to delete. This should
@@ -544,8 +546,12 @@ class Proxy(adapter.Adapter, Generic[T]):
 
     @_check_resource(strict=False)
     def _update(
-        self, resource_type: Type[T], value, base_path=None, **attrs
-    ) -> T:
+        self,
+        resource_type: ty.Type[ResourceType],
+        value,
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Update a resource
 
         :param resource_type: The type of resource to update.
@@ -569,7 +575,12 @@ class Proxy(adapter.Adapter, Generic[T]):
         res = self._get_resource(resource_type, value, **attrs)
         return res.commit(self, base_path=base_path)
 
-    def _create(self, resource_type: Type[T], base_path=None, **attrs):
+    def _create(
+        self,
+        resource_type: ty.Type[ResourceType],
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -594,8 +605,11 @@ class Proxy(adapter.Adapter, Generic[T]):
         return res.create(self, base_path=base_path)
 
     def _bulk_create(
-        self, resource_type: Type[T], data, base_path=None
-    ) -> Generator[T, None, None]:
+        self,
+        resource_type: ty.Type[ResourceType],
+        data,
+        base_path=None,
+    ) -> ty.Generator[ResourceType, None, None]:
         """Create a resource from attributes
 
         :param resource_type: The type of resource to create.
@@ -618,13 +632,13 @@ class Proxy(adapter.Adapter, Generic[T]):
     @_check_resource(strict=False)
     def _get(
         self,
-        resource_type: Type[T],
+        resource_type: ty.Type[ResourceType],
         value=None,
         requires_id=True,
         base_path=None,
         skip_cache=False,
-        **attrs
-    ):
+        **attrs,
+    ) -> ResourceType:
         """Fetch a resource
 
         :param resource_type: The type of resource to get.
@@ -661,12 +675,12 @@ class Proxy(adapter.Adapter, Generic[T]):
 
     def _list(
         self,
-        resource_type: Type[T],
+        resource_type: ty.Type[ResourceType],
         paginated=True,
         base_path=None,
         jmespath_filters=None,
-        **attrs
-    ) -> Generator[T, None, None]:
+        **attrs,
+    ) -> ty.Generator[ResourceType, None, None]:
         """List a resource
 
         :param resource_type: The type of resource to list. This should
@@ -702,8 +716,12 @@ class Proxy(adapter.Adapter, Generic[T]):
         return data
 
     def _head(
-        self, resource_type: Type[T], value=None, base_path=None, **attrs
-    ):
+        self,
+        resource_type: ty.Type[ResourceType],
+        value=None,
+        base_path=None,
+        **attrs,
+    ) -> ResourceType:
         """Retrieve a resource's header
 
         :param resource_type: The type of resource to retrieve.
@@ -736,6 +754,7 @@ class Proxy(adapter.Adapter, Generic[T]):
         identified_resources=None,
         filters=None,
         resource_evaluation_fn=None,
+        skip_resources=None,
     ):
         return None
 
@@ -814,6 +833,20 @@ class Proxy(adapter.Adapter, Generic[T]):
         else:
             return False
 
+    def should_skip_resource_cleanup(self, resource=None, skip_resources=None):
+        if resource is None or skip_resources is None:
+            return False
+
+        resource_name = f"{self.service_type.replace('-', '_')}.{resource}"
+
+        if resource_name in skip_resources:
+            self.log.debug(
+                f"Skipping resource {resource_name} " "in project cleanup"
+            )
+            return True
+
+        return False
+
 
 # TODO(stephenfin): Remove this and all users. Use of this generally indicates
 # a missing Resource type.
