@@ -32,10 +32,12 @@ converted into this Resource class' appropriate components and types
 and then returned to the caller.
 """
 
+import abc
 import collections
 import inspect
 import itertools
 import operator
+import typing as ty
 import urllib.parse
 import warnings
 
@@ -83,14 +85,21 @@ def _convert_type(value, data_type, list_type=None):
         # and the AbsoluteLimits type for an example.
         if isinstance(value, dict):
             return data_type(**value)
-        return data_type(value)
+        try:
+            return data_type(value)
+        except ValueError:
+            # If we can not convert data to the expected type return empty
+            # instance of the expected type.
+            # This is necessary to handle issues like with flavor.swap where
+            # empty string means "0".
+            return data_type()
 
 
-class _BaseComponent:
+class _BaseComponent(abc.ABC):
     # The name this component is being tracked as in the Resource
-    key = None
+    key: str
     # The class to be used for mappings
-    _map_cls = dict
+    _map_cls: ty.Type[ty.Mapping] = dict
 
     #: Marks the property as deprecated.
     deprecated = False
@@ -263,6 +272,8 @@ class Computed(_BaseComponent):
 class _ComponentManager(collections.abc.MutableMapping):
     """Storage of a component type"""
 
+    attributes: ty.Dict[str, ty.Any]
+
     def __init__(self, attributes=None, synchronized=False):
         self.attributes = dict() if attributes is None else attributes.copy()
         self._dirty = set() if synchronized else set(self.attributes.keys())
@@ -321,25 +332,32 @@ class _Request:
 
 
 class QueryParameters:
-    def __init__(self, *names, **mappings):
+    def __init__(
+        self,
+        *names,
+        include_pagination_defaults=True,
+        **mappings,
+    ):
         """Create a dict of accepted query parameters
 
         :param names: List of strings containing client-side query parameter
-                      names. Each name in the list maps directly to the name
-                      expected by the server.
-
+            names. Each name in the list maps directly to the name
+            expected by the server.
         :param mappings: Key-value pairs where the key is the client-side
-                         name we'll accept here and the value is the name
-                         the server expects, e.g, changes_since=changes-since.
-                         Additionally, a value can be a dict with optional keys
-                         name - server-side name,
-                         type - callable to convert from client to server
-                         representation.
+            name we'll accept here and the value is the name
+            the server expects, e.g, ``changes_since=changes-since``.
+            Additionally, a value can be a dict with optional keys:
 
-        By default, both limit and marker are included in the initial mapping
-        as they're the most common query parameters used for listing resources.
+            - ``name`` - server-side name,
+            - ``type`` - callable to convert from client to server
+              representation
+        :param include_pagination_defaults: If true, include default pagination
+            parameters, ``limit`` and ``marker``. These are the most common
+            query parameters used for listing resources in OpenStack APIs.
         """
-        self._mapping = {"limit": "limit", "marker": "marker"}
+        self._mapping = {}
+        if include_pagination_defaults:
+            self._mapping.update({"limit": "limit", "marker": "marker"})
         self._mapping.update({name: name for name in names})
         self._mapping.update(mappings)
 
@@ -350,7 +368,7 @@ class QueryParameters:
             client-side parameter name or server side name.
         :param base_path: Formatted python string of the base url path for
             the resource.
-        : param allow_unknown_params: Exclude query params not known by the
+        :param allow_unknown_params: Exclude query params not known by the
             resource.
 
         :returns: Filtered collection of the supported QueryParameters
@@ -438,14 +456,15 @@ class Resource(dict):
     # will work properly.
 
     #: Singular form of key for resource.
-    resource_key = None
+    resource_key: ty.Optional[str] = None
     #: Plural form of key for resource.
-    resources_key = None
+    resources_key: ty.Optional[str] = None
     #: Key used for pagination links
     pagination_key = None
 
     #: The ID of this resource.
     id = Body("id")
+
     #: The name of this resource.
     name = Body("name")
     #: The OpenStack location of this resource.
@@ -455,10 +474,7 @@ class Resource(dict):
     _query_mapping = QueryParameters()
 
     #: The base part of the URI for this resource.
-    base_path = ""
-
-    #: The service associated with this resource to find the service URL.
-    service = None
+    base_path: str = ""
 
     #: Allow create operation for this resource.
     allow_create = False
@@ -497,22 +513,22 @@ class Resource(dict):
     create_returns_body = None
 
     #: Maximum microversion to use for getting/creating/updating the Resource
-    _max_microversion = None
+    _max_microversion: ty.Optional[str] = None
     #: API microversion (string or None) this Resource was loaded with
     microversion = None
 
     _connection = None
-    _body = None
-    _header = None
-    _uri = None
-    _computed = None
-    _original_body = None
+    _body: _ComponentManager
+    _header: _ComponentManager
+    _uri: _ComponentManager
+    _computed: _ComponentManager
+    _original_body: ty.Dict[str, ty.Any] = {}
     _store_unknown_attrs_as_properties = False
     _allow_unknown_attrs_in_body = False
-    _unknown_attrs_in_body = None
+    _unknown_attrs_in_body: ty.Dict[str, ty.Any] = {}
 
     # Placeholder for aliases as dict of {__alias__:__original}
-    _attr_aliases = {}
+    _attr_aliases: ty.Dict[str, str] = {}
 
     def __init__(self, _synchronized=False, connection=None, **attrs):
         """The base resource
@@ -1061,12 +1077,13 @@ class Resource(dict):
         :return: A dictionary of key/value pairs where keys are named
             as they exist as attributes of this class.
         """
+        mapping: ty.Union[utils.Munch, ty.Dict]
         if _to_munch:
             mapping = utils.Munch()
         else:
             mapping = {}
 
-        components = []
+        components: ty.List[ty.Type[_BaseComponent]] = []
         if body:
             components.append(Body)
         if headers:
@@ -1078,9 +1095,6 @@ class Resource(dict):
                 "At least one of `body`, `headers` or `computed` must be True"
             )
 
-        # isinstance stricly requires this to be a tuple
-        components = tuple(components)
-
         if body and self._allow_unknown_attrs_in_body:
             for key in self._unknown_attrs_in_body:
                 converted = self._attr_to_dict(
@@ -1094,7 +1108,8 @@ class Resource(dict):
         # but is slightly different in that we're looking at an instance
         # and we're mapping names on this class to their actual stored
         # values.
-        for attr, component in self._attributes_iterator(components):
+        # NOTE: isinstance stricly requires components to be a tuple
+        for attr, component in self._attributes_iterator(tuple(components)):
             if original_names:
                 key = component.name
             else:
@@ -1156,6 +1171,7 @@ class Resource(dict):
         *,
         resource_request_key=None,
     ):
+        body: ty.Union[ty.Dict[str, ty.Any], ty.List[ty.Any]]
         if patch:
             if not self._store_unknown_attrs_as_properties:
                 # Default case
@@ -1325,9 +1341,6 @@ class Resource(dict):
         # Resource class that is calling session.$something to be complete.
         if isinstance(session, adapter.Adapter):
             return session
-        if hasattr(session, '_sdk_connection'):
-            service_type = cls.service['service_type']
-            return getattr(session._sdk_connection, service_type)
         raise ValueError(
             "The session argument to Resource methods requires either an"
             " instance of an openstack.proxy.Proxy object or at the very least"
@@ -1584,7 +1597,7 @@ class Resource(dict):
                 "Invalid create method: %s" % cls.create_method
             )
 
-        body = []
+        _body: ty.List[ty.Any] = []
         resources = []
         for attrs in data:
             # NOTE(gryf): we need to create resource objects, since
@@ -1597,9 +1610,12 @@ class Resource(dict):
             request = resource._prepare_request(
                 requires_id=requires_id, base_path=base_path
             )
-            body.append(request.body)
+            _body.append(request.body)
+
+        body: ty.Union[ty.Dict[str, ty.Any], ty.List[ty.Any]] = _body
 
         if prepend_key:
+            assert cls.resources_key
             body = {cls.resources_key: body}
 
         response = method(
@@ -2018,17 +2034,19 @@ class Resource(dict):
             raise exceptions.MethodNotSupported(cls, 'list')
 
         session = cls._get_session(session)
+
         if microversion is None:
             microversion = cls._get_microversion(session, action='list')
 
         if base_path is None:
             base_path = cls.base_path
+
         api_filters = cls._query_mapping._validate(
             params,
             base_path=base_path,
             allow_unknown_params=True,
         )
-        client_filters = dict()
+        client_filters = {}
         # Gather query parameters which are not supported by the server
         for k, v in params.items():
             if (
