@@ -16,7 +16,7 @@
 test_endpoint
 ----------------------------------
 
-Functional tests for `shade` endpoint resource.
+Functional tests for endpoint resource.
 """
 
 import random
@@ -28,9 +28,14 @@ from openstack.tests.functional import base
 
 
 class TestEndpoints(base.KeystoneBaseFunctionalTest):
-
-    endpoint_attributes = ['id', 'region', 'publicurl', 'internalurl',
-                           'service_id', 'adminurl']
+    endpoint_attributes = [
+        'id',
+        'region',
+        'publicurl',
+        'internalurl',
+        'service_id',
+        'adminurl',
+    ]
 
     def setUp(self):
         super(TestEndpoints, self).setUp()
@@ -39,7 +44,8 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
 
         # Generate a random name for services and regions in this test
         self.new_item_name = 'test_' + ''.join(
-            random.choice(string.ascii_lowercase) for _ in range(5))
+            random.choice(string.ascii_lowercase) for _ in range(5)
+        )
 
         self.addCleanup(self._cleanup_services)
         self.addCleanup(self._cleanup_endpoints)
@@ -47,8 +53,9 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
     def _cleanup_endpoints(self):
         exception_list = list()
         for e in self.operator_cloud.list_endpoints():
-            if e.get('region') is not None and \
-                    e['region'].startswith(self.new_item_name):
+            if e.get('region') is not None and e['region'].startswith(
+                self.new_item_name
+            ):
                 try:
                     self.operator_cloud.delete_endpoint(id=e['id'])
                 except Exception as e:
@@ -63,8 +70,9 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
     def _cleanup_services(self):
         exception_list = list()
         for s in self.operator_cloud.list_services():
-            if s['name'] is not None and \
-                    s['name'].startswith(self.new_item_name):
+            if s['name'] is not None and s['name'].startswith(
+                self.new_item_name
+            ):
                 try:
                     self.operator_cloud.delete_service(name_or_id=s['id'])
                 except Exception as e:
@@ -82,15 +90,18 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
         region = list(self.operator_cloud.identity.regions())[0].id
 
         service = self.operator_cloud.create_service(
-            name=service_name, type='test_type',
-            description='this is a test description')
+            name=service_name,
+            type='test_type',
+            description='this is a test description',
+        )
 
         endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
             admin_url='http://admin.url/',
-            region=region)
+            region=region,
+        )
 
         self.assertNotEqual([], endpoints)
         self.assertIsNotNone(endpoints[0].get('id'))
@@ -99,7 +110,8 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
         endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
-            region=region)
+            region=region,
+        )
 
         self.assertNotEqual([], endpoints)
         self.assertIsNotNone(endpoints[0].get('id'))
@@ -108,32 +120,38 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
         ver = self.operator_cloud.config.get_api_version('identity')
         if ver.startswith('2'):
             # NOTE(SamYaple): Update endpoint only works with v3 api
-            self.assertRaises(OpenStackCloudUnavailableFeature,
-                              self.operator_cloud.update_endpoint,
-                              'endpoint_id1')
+            self.assertRaises(
+                OpenStackCloudUnavailableFeature,
+                self.operator_cloud.update_endpoint,
+                'endpoint_id1',
+            )
         else:
             # service operations require existing region. Do not test updating
             # region for now
             region = list(self.operator_cloud.identity.regions())[0].id
 
             service = self.operator_cloud.create_service(
-                name='service1', type='test_type')
+                name='service1', type='test_type'
+            )
             endpoint = self.operator_cloud.create_endpoint(
                 service_name_or_id=service['id'],
                 url='http://admin.url/',
                 interface='admin',
                 region=region,
-                enabled=False)[0]
+                enabled=False,
+            )[0]
 
             new_service = self.operator_cloud.create_service(
-                name='service2', type='test_type')
+                name='service2', type='test_type'
+            )
             new_endpoint = self.operator_cloud.update_endpoint(
                 endpoint.id,
                 service_name_or_id=new_service.id,
                 url='http://public.url/',
                 interface='public',
                 region=region,
-                enabled=True)
+                enabled=True,
+            )
 
             self.assertEqual(new_endpoint.url, 'http://public.url/')
             self.assertEqual(new_endpoint.interface, 'public')
@@ -147,14 +165,17 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
         region = list(self.operator_cloud.identity.regions())[0].id
 
         service = self.operator_cloud.create_service(
-            name=service_name, type='test_type',
-            description='this is a test description')
+            name=service_name,
+            type='test_type',
+            description='this is a test description',
+        )
 
         endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
-            region=region)
+            region=region,
+        )
 
         observed_endpoints = self.operator_cloud.list_endpoints()
         found = False
@@ -170,10 +191,10 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
                         elif e['interface'] == 'public':
                             self.assertEqual('http://public.test/', e['url'])
                     else:
-                        self.assertEqual('http://public.test/',
-                                         e['publicurl'])
-                        self.assertEqual('http://internal.test/',
-                                         e['internalurl'])
+                        self.assertEqual('http://public.test/', e['publicurl'])
+                        self.assertEqual(
+                            'http://internal.test/', e['internalurl']
+                        )
                     self.assertEqual(region, e['region_id'])
 
         self.assertTrue(found, msg='new endpoint not found in endpoints list!')
@@ -184,14 +205,17 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
         region = list(self.operator_cloud.identity.regions())[0].id
 
         service = self.operator_cloud.create_service(
-            name=service_name, type='test_type',
-            description='this is a test description')
+            name=service_name,
+            type='test_type',
+            description='this is a test description',
+        )
 
         endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
-            region=region)
+            region=region,
+        )
 
         self.assertNotEqual([], endpoints)
         for endpoint in endpoints:
@@ -204,5 +228,4 @@ class TestEndpoints(base.KeystoneBaseFunctionalTest):
                 if e['id'] == endpoint['id']:
                     found = True
                     break
-        self.assertEqual(
-            False, found, message='new endpoint was not deleted!')
+        self.assertEqual(False, found, message='new endpoint was not deleted!')
