@@ -14,7 +14,7 @@
 test_users
 ----------------------------------
 
-Functional tests for `shade` user methods.
+Functional tests for user methods.
 """
 
 from openstack.cloud.exc import OpenStackCloudException
@@ -64,7 +64,7 @@ class TestUsers(base.KeystoneBaseFunctionalTest):
         self.assertEqual('admin', user['name'])
 
     def test_search_users(self):
-        users = self.operator_cloud.search_users(filters={'enabled': True})
+        users = self.operator_cloud.search_users(filters={'is_enabled': True})
         self.assertIsNotNone(users)
 
     def test_search_users_jmespath(self):
