@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
 from unittest import mock
 
 from keystoneauth1 import adapter
@@ -21,11 +22,13 @@ from openstack.tests.unit import base
 FAKE_ID = "6685584b-1eac-4da6-b5c3-555430cf68ff"
 IMAGE_METADATA = {
     'container_format': 'bare',
-    'min_ram': '64', 'disk_format': u'qcow2',
+    'min_ram': '64',
+    'disk_format': u'qcow2',
     'image_name': 'TestVM',
     'image_id': '625d4f2c-cf67-4af3-afb6-c7220f766947',
     'checksum': '64d7c1cd2b6f60c92c14662941cb7913',
-    'min_disk': '0', u'size': '13167616'
+    'min_disk': '0',
+    u'size': '13167616',
 }
 
 VOLUME = {
@@ -59,14 +62,13 @@ VOLUME = {
     "OS-SCH-HNT:scheduler_hints": {
         "same_host": [
             "a0cf03a5-d921-4877-bb5c-86d26cf818e1",
-            "8c19174f-4220-44f0-824a-cd1eeef10287"
+            "8c19174f-4220-44f0-824a-cd1eeef10287",
         ]
-    }
+    },
 }
 
 
 class TestVolume(base.TestCase):
-
     def test_basic(self):
         sot = volume.Volume(VOLUME)
         self.assertEqual("volume", sot.resource_key)
@@ -78,15 +80,19 @@ class TestVolume(base.TestCase):
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
-        self.assertDictEqual({"name": "name",
-                              "status": "status",
-                              "all_projects": "all_tenants",
-                              "project_id": "project_id",
-                              "created_at": "created_at",
-                              "updated_at": "updated_at",
-                              "limit": "limit",
-                              "marker": "marker"},
-                             sot._query_mapping._mapping)
+        self.assertDictEqual(
+            {
+                "name": "name",
+                "status": "status",
+                "all_projects": "all_tenants",
+                "project_id": "project_id",
+                "created_at": "created_at",
+                "updated_at": "updated_at",
+                "limit": "limit",
+                "marker": "marker",
+            },
+            sot._query_mapping._mapping,
+        )
 
     def test_create(self):
         sot = volume.Volume(**VOLUME)
@@ -103,33 +109,40 @@ class TestVolume(base.TestCase):
         self.assertEqual(VOLUME["source_volid"], sot.source_volume_id)
         self.assertEqual(VOLUME["metadata"], sot.metadata)
         self.assertEqual(VOLUME["multiattach"], sot.is_multiattach)
-        self.assertEqual(VOLUME["volume_image_metadata"],
-                         sot.volume_image_metadata)
+        self.assertEqual(
+            VOLUME["volume_image_metadata"], sot.volume_image_metadata
+        )
         self.assertEqual(VOLUME["size"], sot.size)
         self.assertEqual(VOLUME["imageRef"], sot.image_id)
         self.assertEqual(VOLUME["os-vol-host-attr:host"], sot.host)
-        self.assertEqual(VOLUME["os-vol-tenant-attr:tenant_id"],
-                         sot.project_id)
-        self.assertEqual(VOLUME["os-vol-mig-status-attr:migstat"],
-                         sot.migration_status)
-        self.assertEqual(VOLUME["os-vol-mig-status-attr:name_id"],
-                         sot.migration_id)
-        self.assertEqual(VOLUME["replication_status"],
-                         sot.replication_status)
+        self.assertEqual(
+            VOLUME["os-vol-tenant-attr:tenant_id"], sot.project_id
+        )
+        self.assertEqual(
+            VOLUME["os-vol-mig-status-attr:migstat"], sot.migration_status
+        )
+        self.assertEqual(
+            VOLUME["os-vol-mig-status-attr:name_id"], sot.migration_id
+        )
+        self.assertEqual(VOLUME["replication_status"], sot.replication_status)
         self.assertEqual(
             VOLUME["os-volume-replication:extended_status"],
-            sot.extended_replication_status)
-        self.assertEqual(VOLUME["consistencygroup_id"],
-                         sot.consistency_group_id)
-        self.assertEqual(VOLUME["os-volume-replication:driver_data"],
-                         sot.replication_driver_data)
+            sot.extended_replication_status,
+        )
+        self.assertEqual(
+            VOLUME["consistencygroup_id"], sot.consistency_group_id
+        )
+        self.assertEqual(
+            VOLUME["os-volume-replication:driver_data"],
+            sot.replication_driver_data,
+        )
         self.assertFalse(sot.is_encrypted)
-        self.assertDictEqual(VOLUME["OS-SCH-HNT:scheduler_hints"],
-                             sot.scheduler_hints)
+        self.assertDictEqual(
+            VOLUME["OS-SCH-HNT:scheduler_hints"], sot.scheduler_hints
+        )
 
 
 class TestVolumeActions(TestVolume):
-
     def setUp(self):
         super(TestVolumeActions, self).setUp()
         self.resp = mock.Mock()
@@ -149,7 +162,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {"os-extend": {"new_size": "20"}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_readonly(self):
         sot = volume.Volume(**VOLUME)
@@ -159,7 +173,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-update_readonly_flag': {'readonly': True}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_readonly_false(self):
         sot = volume.Volume(**VOLUME)
@@ -169,7 +184,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-update_readonly_flag': {'readonly': False}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_bootable(self):
         sot = volume.Volume(**VOLUME)
@@ -179,7 +195,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-set_bootable': {'bootable': True}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_set_volume_bootable_false(self):
         sot = volume.Volume(**VOLUME)
@@ -189,7 +206,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-set_bootable': {'bootable': False}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_reset_status(self):
         sot = volume.Volume(**VOLUME)
@@ -197,25 +215,34 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.reset_status(self.sess, '1', '2', '3'))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-reset_status': {'status': '1', 'attach_status': '2',
-                                    'migration_status': '3'}}
+        body = {
+            'os-reset_status': {
+                'status': '1',
+                'attach_status': '2',
+                'migration_status': '3',
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
-    @mock.patch('openstack.utils.require_microversion', autospec=True,
-                side_effect=[exceptions.SDKException()])
+    @mock.patch(
+        'openstack.utils.require_microversion',
+        autospec=True,
+        side_effect=[exceptions.SDKException()],
+    )
     def test_revert_to_snapshot_before_340(self, mv_mock):
         sot = volume.Volume(**VOLUME)
 
         self.assertRaises(
-            exceptions.SDKException,
-            sot.revert_to_snapshot,
-            self.sess,
-            '1'
+            exceptions.SDKException, sot.revert_to_snapshot, self.sess, '1'
         )
 
-    @mock.patch('openstack.utils.require_microversion', autospec=True,
-                side_effect=[None])
+    @mock.patch(
+        'openstack.utils.require_microversion',
+        autospec=True,
+        side_effect=[None],
+    )
     def test_revert_to_snapshot_after_340(self, mv_mock):
         sot = volume.Volume(**VOLUME)
 
@@ -224,7 +251,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'revert': {'snapshot_id': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
         mv_mock.assert_called_with(self.sess, '3.40')
 
     def test_attach_instance(self):
@@ -235,7 +263,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-attach': {'mountpoint': '1', 'instance_uuid': '2'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_attach_host(self):
         sot = volume.Volume(**VOLUME)
@@ -245,16 +274,13 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-attach': {'mountpoint': '1', 'host_name': '2'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_attach_error(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertRaises(
-            ValueError,
-            sot.attach,
-            self.sess,
-            '1')
+        self.assertRaises(ValueError, sot.attach, self.sess, '1')
 
     def test_detach(self):
         sot = volume.Volume(**VOLUME)
@@ -264,19 +290,23 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-detach': {'attachment_id': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_detach_force(self):
         sot = volume.Volume(**VOLUME)
 
         self.assertIsNone(
-            sot.detach(self.sess, '1', force=True, connector={'a': 'b'}))
+            sot.detach(self.sess, '1', force=True, connector={'a': 'b'})
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-force_detach': {'attachment_id': '1',
-                                    'connector': {'a': 'b'}}}
+        body = {
+            'os-force_detach': {'attachment_id': '1', 'connector': {'a': 'b'}}
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_unmanage(self):
         sot = volume.Volume(**VOLUME)
@@ -286,7 +316,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-unmanage': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_retype(self):
         sot = volume.Volume(**VOLUME)
@@ -296,7 +327,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-retype': {'new_type': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_retype_mp(self):
         sot = volume.Volume(**VOLUME)
@@ -306,7 +338,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-retype': {'new_type': '1', 'migration_policy': '2'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_migrate(self):
         sot = volume.Volume(**VOLUME)
@@ -316,33 +349,55 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-migrate_volume': {'host': '1'}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_migrate_flags(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(sot.migrate(self.sess, host='1',
-                                      force_host_copy=True, lock_volume=True))
+        self.assertIsNone(
+            sot.migrate(
+                self.sess, host='1', force_host_copy=True, lock_volume=True
+            )
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume': {'host': '1', 'force_host_copy': True,
-                                      'lock_volume': True}}
+        body = {
+            'os-migrate_volume': {
+                'host': '1',
+                'force_host_copy': True,
+                'lock_volume': True,
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
-    @mock.patch('openstack.utils.require_microversion', autospec=True,
-                side_effect=[None])
+    @mock.patch(
+        'openstack.utils.require_microversion',
+        autospec=True,
+        side_effect=[None],
+    )
     def test_migrate_cluster(self, mv_mock):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(sot.migrate(self.sess, cluster='1',
-                                      force_host_copy=True, lock_volume=True))
+        self.assertIsNone(
+            sot.migrate(
+                self.sess, cluster='1', force_host_copy=True, lock_volume=True
+            )
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume': {'cluster': '1', 'force_host_copy': True,
-                                      'lock_volume': True}}
+        body = {
+            'os-migrate_volume': {
+                'cluster': '1',
+                'force_host_copy': True,
+                'lock_volume': True,
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
         mv_mock.assert_called_with(self.sess, '3.16')
 
     def test_complete_migration(self):
@@ -351,22 +406,27 @@ class TestVolumeActions(TestVolume):
         self.assertIsNone(sot.complete_migration(self.sess, new_volume_id='1'))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume_completion': {'new_volume': '1', 'error':
-                                                 False}}
+        body = {
+            'os-migrate_volume_completion': {'new_volume': '1', 'error': False}
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_complete_migration_error(self):
         sot = volume.Volume(**VOLUME)
 
-        self.assertIsNone(sot.complete_migration(
-            self.sess, new_volume_id='1', error=True))
+        self.assertIsNone(
+            sot.complete_migration(self.sess, new_volume_id='1', error=True)
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-migrate_volume_completion': {'new_volume': '1', 'error':
-                                                 True}}
+        body = {
+            'os-migrate_volume_completion': {'new_volume': '1', 'error': True}
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_force_delete(self):
         sot = volume.Volume(**VOLUME)
@@ -376,7 +436,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-force_delete': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_upload_image(self):
         sot = volume.Volume(**VOLUME)
@@ -390,15 +451,16 @@ class TestVolumeActions(TestVolume):
         self.assertDictEqual({'a': 'b'}, sot.upload_to_image(self.sess, '1'))
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-volume_upload_image': {
-            'image_name': '1',
-            'force': False
-        }}
+        body = {'os-volume_upload_image': {'image_name': '1', 'force': False}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
-    @mock.patch('openstack.utils.require_microversion', autospec=True,
-                side_effect=[None])
+    @mock.patch(
+        'openstack.utils.require_microversion',
+        autospec=True,
+        side_effect=[None],
+    )
     def test_upload_image_args(self, mv_mock):
         sot = volume.Volume(**VOLUME)
 
@@ -410,21 +472,30 @@ class TestVolumeActions(TestVolume):
 
         self.assertDictEqual(
             {'a': 'b'},
-            sot.upload_to_image(self.sess, '1', disk_format='2',
-                                container_format='3', visibility='4',
-                                protected='5'))
+            sot.upload_to_image(
+                self.sess,
+                '1',
+                disk_format='2',
+                container_format='3',
+                visibility='4',
+                protected='5',
+            ),
+        )
 
         url = 'volumes/%s/action' % FAKE_ID
-        body = {'os-volume_upload_image': {
-            'image_name': '1',
-            'force': False,
-            'disk_format': '2',
-            'container_format': '3',
-            'visibility': '4',
-            'protected': '5'
-        }}
+        body = {
+            'os-volume_upload_image': {
+                'image_name': '1',
+                'force': False,
+                'disk_format': '2',
+                'container_format': '3',
+                'visibility': '4',
+                'protected': '5',
+            }
+        }
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
         mv_mock.assert_called_with(self.sess, '3.1')
 
     def test_reserve(self):
@@ -435,7 +506,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-reserve': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_unreserve(self):
         sot = volume.Volume(**VOLUME)
@@ -445,7 +517,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-unreserve': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_begin_detaching(self):
         sot = volume.Volume(**VOLUME)
@@ -455,7 +528,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-begin_detaching': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_abort_detaching(self):
         sot = volume.Volume(**VOLUME)
@@ -465,7 +539,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-roll_detaching': {}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_init_attachment(self):
         sot = volume.Volume(**VOLUME)
@@ -475,7 +550,8 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-initialize_connection': {'connector': {'a': 'b'}}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
 
     def test_terminate_attachment(self):
         sot = volume.Volume(**VOLUME)
@@ -485,4 +561,40 @@ class TestVolumeActions(TestVolume):
         url = 'volumes/%s/action' % FAKE_ID
         body = {'os-terminate_connection': {'connector': {'a': 'b'}}}
         self.sess.post.assert_called_with(
-            url, json=body, microversion=sot._max_microversion)
+            url, json=body, microversion=sot._max_microversion
+        )
+
+    def test__prepare_request_body(self):
+        sot = volume.Volume(**VOLUME)
+        body = sot._prepare_request_body(patch=False, prepend_key=True)
+        original_body = copy.deepcopy(sot._body.dirty)
+        # Verify that scheduler hints aren't modified after preparing request
+        # but also not part of 'volume' JSON object
+        self.assertEqual(
+            original_body['OS-SCH-HNT:scheduler_hints'],
+            body['OS-SCH-HNT:scheduler_hints'],
+        )
+        # Pop scheduler hints to verify other parameters in body
+        original_body.pop('OS-SCH-HNT:scheduler_hints')
+        # Verify that other request parameters are same but in 'volume' JSON
+        self.assertEqual(original_body, body['volume'])
+
+    def test_create_scheduler_hints(self):
+        sot = volume.Volume(**VOLUME)
+        sot._translate_response = mock.Mock()
+        sot.create(self.sess)
+
+        url = '/volumes'
+        volume_body = copy.deepcopy(VOLUME)
+        scheduler_hints = volume_body.pop('OS-SCH-HNT:scheduler_hints')
+        body = {
+            "volume": volume_body,
+            'OS-SCH-HNT:scheduler_hints': scheduler_hints,
+        }
+        self.sess.post.assert_called_with(
+            url,
+            json=body,
+            microversion='3.0',
+            headers={},
+            params={},
+        )
