@@ -10,9 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.network.v2 import segment
 from openstack.tests.unit import base
 
-from openstack.network.v2 import segment
 
 IDENTIFIER = 'IDENTIFIER'
 EXAMPLE = {
@@ -27,17 +27,15 @@ EXAMPLE = {
 
 
 class TestSegment(base.TestCase):
-
     def test_basic(self):
         sot = segment.Segment()
         self.assertEqual('segment', sot.resource_key)
         self.assertEqual('segments', sot.resources_key)
         self.assertEqual('/segments', sot.base_path)
-        self.assertEqual('network', sot.service.service_type)
 
         self.assertTrue(sot.allow_create)
-        self.assertTrue(sot.allow_get)
-        self.assertTrue(sot.allow_update)
+        self.assertTrue(sot.allow_fetch)
+        self.assertTrue(sot.allow_commit)
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
