@@ -14,6 +14,7 @@ import copy
 import queue
 from unittest import mock
 
+from keystoneauth1 import session
 from testscenarios import load_tests_apply_scenarios as load_tests  # noqa
 
 from openstack import exceptions
@@ -622,7 +623,7 @@ class TestProxyCache(base.TestCase):
             cloud_config_fixture='clouds_cache.yaml'
         )
 
-        self.session = mock.Mock()
+        self.session = mock.Mock(spec=session.Session)
         self.session._sdk_connection = self.cloud
         self.session.get_project_id = mock.Mock(return_value='fake_prj')
 
@@ -651,10 +652,11 @@ class TestProxyCache(base.TestCase):
             connect_retries=mock.ANY,
             raise_exc=mock.ANY,
             global_request_id=mock.ANY,
-            endpoint_filter=mock.ANY,
-            headers=mock.ANY,
             microversion=mock.ANY,
             params=mock.ANY,
+            endpoint_filter=mock.ANY,
+            headers=mock.ANY,
+            rate_semaphore=mock.ANY,
         )
         self.assertIn(self._get_key(1), self.cloud._api_cache_keys)
 
@@ -728,6 +730,7 @@ class TestProxyCleanup(base.TestCase):
         self.res_no_updated.created_at = '2020-01-02T03:04:05'
 
         self.sot = proxy.Proxy(self.session)
+        self.sot.service_type = "block-storage"
 
         self.delete_mock = mock.Mock()
 
@@ -867,3 +870,12 @@ class TestProxyCleanup(base.TestCase):
             )
         )
         self.assertEqual(self.res, q.get_nowait())
+
+    def test_should_skip_resource_cleanup(self):
+        excluded = ["block_storage.backup"]
+        self.assertTrue(
+            self.sot.should_skip_resource_cleanup("backup", excluded)
+        )
+        self.assertFalse(
+            self.sot.should_skip_resource_cleanup("volume", excluded)
+        )
